@@ -24,19 +24,21 @@ See the GNU General Public License for more details.
 #include <fcntl.h>
 #include <net/bpf.h>
 #include <net/if.h>
+#include <string.h>
+#include <stdio.h>
 #include "arp.h"
 
-int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
+int send_packet_bsd(const char *dev, u_char *packet, u_int packetsize)
 {
   int bpffd, i;
-  char bpfdev[10];
+  char bpfdev[12];
 
   if( (strlen(dev) == 0) ||
       (packetsize == 0) )
-    return -1;
+    return 0;
 
   // Open a bpf device
-  for(i = 0; i < 9; i++)
+  for(i = 0; i < 512; i++)
     {
       sprintf(bpfdev,"/dev/bpf%d",i);
       if((bpffd = open(bpfdev,O_WRONLY)) > 0)
@@ -48,6 +50,7 @@ int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
   if(bpffd < 0)
     {
       perror("open bpf");
+      return 0;
     }
   else
     {
@@ -63,5 +66,5 @@ int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
       close(bpffd);
     }
 
-  return 0;
+  return 1;
 }
